@@ -52,3 +52,21 @@ LUX_API = ApiEndpoint(
     api_module=constants.LUX_API_KEY,
     port=443,
 )
+
+
+CANARY_LIGHT_API = ApiEndpoint(
+    protocol="https",
+    host="canary.shimmercat.com",
+    version="2020.1",
+    api_module=constants.LIGHT_API_KEY,
+    port=443,
+)
+
+
+CANARY_LUX_API = ApiEndpoint(
+    protocol="https",
+    host="canary.shimmercat.com",
+    version="2020.4",
+    api_module=constants.LUX_API_KEY,
+    port=443,
+)
